package cl.utfsm.elo.khott.cliente.gui;

import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.TitledBorder;
import javax.swing.event.*;
import java.rmi.*;
import java.net.MalformedURLException;
import cl.utfsm.elo.khott.servidor.DatosInterfaz;

/**
 * Construye la columna de los datos a interactuar.
 * @author Janther
 */
public class ColumnaDatos extends JPanel {

	/**
     * Numero Serial de la clase.
     */
    private static final long serialVersionUID = 1002;
    /**
     * Panel con pestaas.
     */
    private Panel panel;
    /**
     * Sala Seleccionada.
     */
    private JComboBox sala = new JComboBox();
    /**
     * Semana inicial de la Reserva.
     */
    private JSpinner desde;
    /**
     * Semana final de la Reserva.
     */
    private JSpinner hasta;
    /**
     * Cupo solicitado para la reserva.
     */
    private JSpinner cupo;
    /**
     * Semana a Mostrarse.
     */
    private JSpinner actual;
    /**
     * Coneccion RMI.
     */
    private String conection;

    /**
     * Constructor de la clase.
     * @param conexion Coneccion RMI.
     * @param pane Panel con pestaas.
     */
    public ColumnaDatos(String conexion, Panel pane) {
        super();
        panel = pane;
        conection = conexion;

        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));

        JPanel panelSalas = new JPanel();
        panelSalas.setLayout(new BoxLayout(panelSalas, BoxLayout.Y_AXIS));
        panelSalas.setBorder(new TitledBorder(panelSalas.getBorder(), "Salas"));
        try {
            DatosInterfaz data = (DatosInterfaz)
                    Naming.lookup("rmi://" + conection + "/Datos");
            sala = data.comboSalas();
            sala.addActionListener(new Actualiza());
            panelSalas.add(sala);
	    }
        catch (MalformedURLException murle) { 
            System.out.println(); 
            System.out.println("MalformedURLException"); 
            System.out.println(murle); 
        } 
        catch (RemoteException re) { 
            System.out.println(); 
            System.out.println("RemoteException"); 
            System.out.println(re); 
        } 
        catch (NotBoundException nbe) { 
            System.out.println(); 
            System.out.println("NotBoundException"); 
            System.out.println(nbe); 
        }

        JPanel panelSemanas = new JPanel();
        panelSemanas.setLayout(new BoxLayout(panelSemanas, BoxLayout.Y_AXIS));
        panelSemanas.setBorder(new TitledBorder(panelSemanas.getBorder(), "Semanas"));
        JPanel semanaMin = new JPanel();
        semanaMin.setLayout(new BoxLayout(semanaMin, BoxLayout.Y_AXIS));
        semanaMin.add(new JLabel("Desde:"));
        desde = new JSpinner(
                new SpinnerNumberModel(1, 1, 51, 1));
        desde.addChangeListener(new Actualiza());
        semanaMin.add(desde);
        JPanel semanaMax = new JPanel();
        semanaMax.setLayout(new BoxLayout(semanaMax, BoxLayout.Y_AXIS));
        semanaMax.add(new JLabel("Hasta:"));
        hasta = new JSpinner(
                new SpinnerNumberModel(51, 1, 51, 1));
        hasta.addChangeListener(new Actualiza());
        semanaMax.add(hasta);
        JPanel semanaActual = new JPanel();
        semanaActual.setLayout(new BoxLayout(semanaActual, BoxLayout.Y_AXIS));
        semanaActual.add(new JLabel("Ver Semana:"));
        actual = new JSpinner(
                new SpinnerNumberModel(1, 1, 51, 1));
        actual.addChangeListener(new Actualiza());
        semanaActual.add(actual);
        panelSemanas.add(semanaMin);
        panelSemanas.add(semanaMax);
        panelSemanas.add(semanaActual);
        
        JPanel panelCupo = new JPanel();
        panelCupo.setLayout(new BoxLayout(panelCupo, BoxLayout.Y_AXIS));
        panelCupo.setBorder(new TitledBorder(panelCupo.getBorder(), "Cupo"));
        cupo = new JSpinner(
                new SpinnerNumberModel(30, 0, null, 10));
        cupo.addChangeListener(new Actualiza());
        panelCupo.add(cupo);

        add(panelSalas);
        add(panelSemanas);
        add(panelCupo);
        JButton reserva = new JButton("Reserva");
        reserva.addActionListener(new Reservar());
        add(reserva);
    }

    /**
     * Clase que implementa la actualizacion de los paneles cuando cambian los
     * datos.
     * @author Janther
     */
    private class Actualiza implements ChangeListener, ActionListener{

        /**
         * Constructor de la clase.
         */
        public Actualiza() {}

        /**
         * Metodo que efectua la actualizacion.
         */
        private void cambio() {
            panel.actualiza(conection,
                    (String) sala.getSelectedItem(),
                    (Integer) desde.getValue(),
                    (Integer) hasta.getValue(),
                    (Integer) cupo.getValue(),
                    (Integer) actual.getValue());
        }

        /**
         * Metodo que implementa la interfaz de cambio.
         */
        public void stateChanged(ChangeEvent e) {
            cambio();
        }

        /**
         * Metodo que implementa la interfaz de accion.
         */
        public void actionPerformed(ActionEvent e) {
            cambio();
        }
    }

    /**
     * Clase Que implementa la reserva de una sala.
     * @author Janther
     */
    private class Reservar implements ActionListener{

        /**
         * Constructor de la clase.
         */
        public Reservar() {}

        /**
         * Metodo que implementa la interfaz de accion.
         */
        public void actionPerformed(ActionEvent e) {
            panel.reserva(conection,
                    (String) sala.getSelectedItem(),
                    (Integer) desde.getValue(),
                    (Integer) hasta.getValue(),
                    (Integer) cupo.getValue(),
                    (Integer) actual.getValue());
        }
    }
}
