package cl.utfsm.elo.khott.cliente.gui;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;
import javax.swing.*;
import cl.utfsm.elo.khott.servidor.*;

/**
 * La clase Dibujo es el panel donde estaran las formas.
 */
public class Panel extends JTabbedPane {
	/**
     * Numero Serial de la clase.
     */
    private static final long serialVersionUID = 1005;

    /**
     * Constructor de la clase.
     * @param conexion Conexion RMI.
     */
    public Panel (String conexion) {
        super();
        PanelHorario horario = new PanelHorario(conexion, "A101", 1);
        PanelSalas salas = new PanelSalas(conexion);

        addTab("Salas", salas);
        addTab("Horario", horario);
    }

    /**
     * Metodo que actualiza las vistas.
     * @param conexion conexion RMI.
     * @param sala id de la sala seleccionada.
     * @param min semana inicial de la Reserva.
     * @param max semana final de la Reserva.
     * @param cupo cupo de la reserva.
     * @param actual semana que se esta observando.
     */
    public void actualiza(String conexion,
            String sala,
            int min,
            int max,
            int cupo,
            int actual){
    	int selected = this.getSelectedIndex();
        removeAll();
        PanelHorario horario = new PanelHorario(conexion, sala, actual);
        PanelSalas salas = new PanelSalas(conexion, min, max, cupo);
        addTab("Salas", salas);
        addTab("Horario", horario);
        setSelectedIndex(selected);
    }

    /**
     * Metodo que realiza la Reserva.
     * @param conexion conexion RMI.
     * @param sala id de la sala seleccionada.
     * @param min semana inicial de la Reserva.
     * @param max semana final de la Reserva.
     * @param cupo cupo de la reserva.
     * @param actual semana que se esta observando.
     */
    public void reserva(String conexion,
            String sala,
            int min,
            int max,
            int cupo,
            int actual) {
        try {
        	SalaInterfaz aula = (SalaInterfaz)
                    Naming.lookup("rmi://" + conexion + "/" + sala);
    	    aula.addReserva(new Reserva(min, max,
    	    		((PanelHorario) getComponentAt(1)).getDia(),
    	    		((PanelHorario) getComponentAt(1)).getBloque()));
    	    actualiza(conexion, sala, min, max, cupo, actual);
	    }
        catch (MalformedURLException murle) { 
            System.out.println(); 
            System.out.println("MalformedURLException"); 
            System.out.println(murle); 
        } 
        catch (RemoteException re) { 
            System.out.println(); 
            System.out.println("RemoteException"); 
            System.out.println(re); 
        } 
        catch (NotBoundException nbe) { 
            System.out.println(); 
            System.out.println("NotBoundException"); 
            System.out.println(nbe); 
        }
    }
}
