package cl.utfsm.elo.khott.cliente.gui;

import javax.swing.*;
import cl.utfsm.elo.khott.servidor.*;
import java.util.*;
import java.awt.*;
import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;
import javax.swing.table.*;

public class PanelSalas extends JPanel {

	/**
     * Numero Serial de la clase.
     */
    private static final long serialVersionUID = 1003;
    private int min = 1;
    private int max = 51;
    private int alumnos = 30;

    public PanelSalas(String conexion, int minimo, int maximo, int cupo) {
    	super(new GridLayout(1,0));
    	min = minimo;
    	max = maximo;
    	alumnos = cupo;
        
        JTable tabla = crearTabla(conexion);
        tabla.setRowSelectionAllowed(false);
        tabla.setColumnSelectionAllowed(false);
        tabla.setCellSelectionEnabled(true);
        tabla.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        tabla.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        tabla.setDragEnabled(false);
        tabla.setPreferredScrollableViewportSize(new Dimension(600, 120));
        for (int i = 0; i < tabla.getColumnCount(); i++){
        	TableColumn tc = tabla.getColumnModel().getColumn(i);
        	tc.setCellRenderer(new SalaRenderer());
        }
    	
        JScrollPane scrollPane = new JScrollPane(tabla);
        add(scrollPane);
        setOpaque(true);
        setSize(600,145);
    }
    public PanelSalas(String conexion) {
        super(new GridLayout(1,0));
        JTable tabla = crearTabla(conexion);

        tabla.setRowSelectionAllowed(false);
        tabla.setColumnSelectionAllowed(false);
        tabla.setCellSelectionEnabled(true);
        tabla.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        tabla.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        tabla.setDragEnabled(false);
        tabla.setPreferredScrollableViewportSize(new Dimension(600, 120));
        for (int i = 0; i < tabla.getColumnCount(); i++){
        	TableColumn tc = tabla.getColumnModel().getColumn(i);
        	tc.setCellRenderer(new SalaRenderer());
        }
    	
        JScrollPane scrollPane = new JScrollPane(tabla);
        add(scrollPane);
        setOpaque(true);
        setSize(600,145);
    }

	private JTable crearTabla(String conexion){
		JTable tabla = new JTable();
        try {
            DatosInterfaz datos = (DatosInterfaz)
                    Naming.lookup("rmi://" + conexion + "/Datos");
            final Vector < String > salas = datos.vectorSalas();
            final Vector < String > edificios = datos.vectorEdificios();
	        Vector < Vector > rowData = new Vector <Vector> ();
	        Vector < Cell > data = new Vector < Cell > ();
	        while (salas.size() > 0){
	            data.clear();
	        	for (int i = 0; i < edificios.size(); i++) {
	        		boolean added = false;
	        	    for (int j = 0; j < salas.size(); j++) {
	        	        if (salas.get(j).startsWith(edificios.get(i)) &&
	        	                !added) {
	        	        	SalaInterfaz sala = (SalaInterfaz)
                                    Naming.lookup("rmi://" +
                                    conexion + "/" + salas.get(j));
	        	        	sala.setColores(min, max, alumnos);
	        	        	data.add(new Cell(
	        	        	            sala.getId(),
	        	        	            sala.getColorFondo(),
	        	        	            sala.getColorText(),
	        	        	            sala.getToolTip()));
	        	            added = true;
	        	            salas.remove(j);
	        	        }
	        	    }
	        	    if (!added) {
	        	        data.add(new Cell(
    	        	            "",
    	        	            Color.WHITE,
    	        	            Color.WHITE,
    	        	            ""));
	        	    }
	        	}
	        	rowData.add((Vector)data.clone());
	        }
	        tabla = new JTable(rowData, edificios);
	    }
        catch (MalformedURLException murle) { 
            System.out.println(); 
            System.out.println("MalformedURLException"); 
            System.out.println(murle); 
        } 
        catch (RemoteException re) { 
            System.out.println(); 
            System.out.println("RemoteException"); 
            System.out.println(re); 
        } 
        catch (NotBoundException nbe) { 
            System.out.println(); 
            System.out.println("NotBoundException"); 
            System.out.println(nbe); 
        }
        return tabla;
	}
}
